@@ -24,7 +24,7 @@ class QueryVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major_version, self.minor_version = unpacker.unpack("xx2x4xII16x")
+        self.major_version, self.minor_version = unpacker.unpack("=xx2x4xII16x")
         self.bufsize = unpacker.offset - base
 
 
@@ -40,7 +40,7 @@ class GetOverlayWindowReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.overlay_win,) = unpacker.unpack("xx2x4xI20x")
+        (self.overlay_win,) = unpacker.unpack("=xx2x4xI20x")
         self.bufsize = unpacker.offset - base
 
 
