@@ -44,7 +44,7 @@ class DRI2Buffer(xcffib.Struct):
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
         self.attachment, self.name, self.pitch, self.cpp, self.flags = unpacker.unpack(
-            "IIIII"
+            "=IIIII"
         )
         self.bufsize = unpacker.offset - base
 
@@ -78,7 +78,7 @@ class AttachFormat(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.attachment, self.format = unpacker.unpack("II")
+        self.attachment, self.format = unpacker.unpack("=II")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -104,7 +104,7 @@ class QueryVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major_version, self.minor_version = unpacker.unpack("xx2x4xII")
+        self.major_version, self.minor_version = unpacker.unpack("=xx2x4xII")
         self.bufsize = unpacker.offset - base
 
 
@@ -121,7 +121,7 @@ class ConnectReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.driver_name_length, self.device_name_length = unpacker.unpack(
-            "xx2x4xII16x"
+            "=xx2x4xII16x"
         )
         self.driver_name = xcffib.List(unpacker, "c", self.driver_name_length)
         unpacker.pad("c")
@@ -147,7 +147,7 @@ class AuthenticateReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.authenticated,) = unpacker.unpack("xx2x4xI")
+        (self.authenticated,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -163,7 +163,7 @@ class GetBuffersReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.width, self.height, self.count = unpacker.unpack("xx2x4xIII12x")
+        self.width, self.height, self.count = unpacker.unpack("=xx2x4xIII12x")
         self.buffers = xcffib.List(unpacker, DRI2Buffer, self.count)
         self.bufsize = unpacker.offset - base
 
@@ -180,7 +180,7 @@ class CopyRegionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x")
+        unpacker.unpack("=xx2x4x")
         self.bufsize = unpacker.offset - base
 
 
@@ -196,7 +196,7 @@ class GetBuffersWithFormatReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.width, self.height, self.count = unpacker.unpack("xx2x4xIII12x")
+        self.width, self.height, self.count = unpacker.unpack("=xx2x4xIII12x")
         self.buffers = xcffib.List(unpacker, DRI2Buffer, self.count)
         self.bufsize = unpacker.offset - base
 
@@ -213,7 +213,7 @@ class SwapBuffersReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.swap_hi, self.swap_lo = unpacker.unpack("xx2x4xII")
+        self.swap_hi, self.swap_lo = unpacker.unpack("=xx2x4xII")
         self.bufsize = unpacker.offset - base
 
 
@@ -230,7 +230,7 @@ class GetMSCReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.ust_hi, self.ust_lo, self.msc_hi, self.msc_lo, self.sbc_hi, self.sbc_lo = (
-            unpacker.unpack("xx2x4xIIIIII")
+            unpacker.unpack("=xx2x4xIIIIII")
         )
         self.bufsize = unpacker.offset - base
 
@@ -248,7 +248,7 @@ class WaitMSCReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.ust_hi, self.ust_lo, self.msc_hi, self.msc_lo, self.sbc_hi, self.sbc_lo = (
-            unpacker.unpack("xx2x4xIIIIII")
+            unpacker.unpack("=xx2x4xIIIIII")
         )
         self.bufsize = unpacker.offset - base
 
@@ -266,7 +266,7 @@ class WaitSBCReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.ust_hi, self.ust_lo, self.msc_hi, self.msc_lo, self.sbc_hi, self.sbc_lo = (
-            unpacker.unpack("xx2x4xIIIIII")
+            unpacker.unpack("=xx2x4xIIIIII")
         )
         self.bufsize = unpacker.offset - base
 
@@ -284,7 +284,7 @@ class GetParamReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.is_param_recognized, self.value_hi, self.value_lo = unpacker.unpack(
-            "xB2x4xII"
+            "=xB2x4xII"
         )
         self.bufsize = unpacker.offset - base
 
@@ -309,7 +309,7 @@ class BufferSwapCompleteEvent(xcffib.Event):
             self.msc_hi,
             self.msc_lo,
             self.sbc,
-        ) = unpacker.unpack("xx2xH2xIIIIII")
+        ) = unpacker.unpack("=xx2xH2xIIIIII")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -356,7 +356,7 @@ class InvalidateBuffersEvent(xcffib.Event):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
-        (self.drawable,) = unpacker.unpack("xx2xI")
+        (self.drawable,) = unpacker.unpack("=xx2xI")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
