@@ -125,7 +125,7 @@ class PictFormatError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -147,7 +147,7 @@ class PictureError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -169,7 +169,7 @@ class PictOpError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -191,7 +191,7 @@ class GlyphSetError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -213,7 +213,7 @@ class GlyphError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -244,7 +244,7 @@ class DIRECTFORMAT(xcffib.Struct):
             self.blue_mask,
             self.alpha_shift,
             self.alpha_mask,
-        ) = unpacker.unpack("HHHHHHHH")
+        ) = unpacker.unpack("=HHHHHHHH")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -298,9 +298,9 @@ class PICTFORMINFO(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.id, self.type, self.depth = unpacker.unpack("IBB2x")
+        self.id, self.type, self.depth = unpacker.unpack("=IBB2x")
         self.direct = DIRECTFORMAT(unpacker)
-        (self.colormap,) = unpacker.unpack("I")
+        (self.colormap,) = unpacker.unpack("=I")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -333,7 +333,7 @@ class PICTVISUAL(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.visual, self.format = unpacker.unpack("II")
+        self.visual, self.format = unpacker.unpack("=II")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -359,7 +359,7 @@ class PICTDEPTH(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.depth, self.num_visuals = unpacker.unpack("BxH4x")
+        self.depth, self.num_visuals = unpacker.unpack("=BxH4x")
         self.visuals = xcffib.List(unpacker, PICTVISUAL, self.num_visuals)
         self.bufsize = unpacker.offset - base
 
@@ -386,7 +386,7 @@ class PICTSCREEN(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.num_depths, self.fallback = unpacker.unpack("II")
+        self.num_depths, self.fallback = unpacker.unpack("=II")
         self.depths = xcffib.List(unpacker, PICTDEPTH, self.num_depths)
         self.bufsize = unpacker.offset - base
 
@@ -414,7 +414,7 @@ class INDEXVALUE(xcffib.Struct):
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
         self.pixel, self.red, self.green, self.blue, self.alpha = unpacker.unpack(
-            "IHHHH"
+            "=IHHHH"
         )
         self.bufsize = unpacker.offset - base
 
@@ -448,7 +448,7 @@ class COLOR(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.red, self.green, self.blue, self.alpha = unpacker.unpack("HHHH")
+        self.red, self.green, self.blue, self.alpha = unpacker.unpack("=HHHH")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -476,7 +476,7 @@ class POINTFIX(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.x, self.y = unpacker.unpack("ii")
+        self.x, self.y = unpacker.unpack("=ii")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -580,7 +580,7 @@ class TRAPEZOID(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.top, self.bottom = unpacker.unpack("ii")
+        self.top, self.bottom = unpacker.unpack("=ii")
         self.left = LINEFIX(unpacker)
         unpacker.pad(LINEFIX)
         self.right = LINEFIX(unpacker)
@@ -620,7 +620,7 @@ class GLYPHINFO(xcffib.Struct):
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
         self.width, self.height, self.x, self.y, self.x_off, self.y_off = (
-            unpacker.unpack("HHhhhh")
+            unpacker.unpack("=HHhhhh")
         )
         self.bufsize = unpacker.offset - base
 
@@ -661,7 +661,7 @@ class QueryVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major_version, self.minor_version = unpacker.unpack("xx2x4xII16x")
+        self.major_version, self.minor_version = unpacker.unpack("=xx2x4xII16x")
         self.bufsize = unpacker.offset - base
 
 
@@ -683,7 +683,7 @@ class QueryPictFormatsReply(xcffib.Reply):
             self.num_depths,
             self.num_visuals,
             self.num_subpixel,
-        ) = unpacker.unpack("xx2x4xIIIII4x")
+        ) = unpacker.unpack("=xx2x4xIIIII4x")
         self.formats = xcffib.List(unpacker, PICTFORMINFO, self.num_formats)
         unpacker.pad(PICTSCREEN)
         self.screens = xcffib.List(unpacker, PICTSCREEN, self.num_screens)
@@ -704,7 +704,7 @@ class QueryPictIndexValuesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.num_values,) = unpacker.unpack("xx2x4xI20x")
+        (self.num_values,) = unpacker.unpack("=xx2x4xI20x")
         self.values = xcffib.List(unpacker, INDEXVALUE, self.num_values)
         self.bufsize = unpacker.offset - base
 
@@ -731,7 +731,7 @@ class TRANSFORM(xcffib.Struct):
             self.matrix31,
             self.matrix32,
             self.matrix33,
-        ) = unpacker.unpack("iiiiiiiii")
+        ) = unpacker.unpack("=iiiiiiiii")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -788,7 +788,7 @@ class QueryFiltersReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.num_aliases, self.num_filters = unpacker.unpack("xx2x4xII16x")
+        self.num_aliases, self.num_filters = unpacker.unpack("=xx2x4xII16x")
         self.aliases = xcffib.List(unpacker, "H", self.num_aliases)
         unpacker.pad(xproto.STR)
         self.filters = xcffib.List(unpacker, xproto.STR, self.num_filters)
@@ -807,7 +807,7 @@ class ANIMCURSORELT(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.cursor, self.delay = unpacker.unpack("II")
+        self.cursor, self.delay = unpacker.unpack("=II")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -833,7 +833,7 @@ class SPANFIX(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.l, self.r, self.y = unpacker.unpack("iii")
+        self.l, self.r, self.y = unpacker.unpack("=iii")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
