@@ -37,7 +37,7 @@ class QueryVersionReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.server_major_version, self.server_minor_version = unpacker.unpack(
-            "xx2x4xHH20x"
+            "=xx2x4xHH20x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -61,7 +61,7 @@ class QueryInfoReply(xcffib.Reply):
             self.ms_since_user_input,
             self.event_mask,
             self.kind,
-        ) = unpacker.unpack("xB2x4xIIIIB7x")
+        ) = unpacker.unpack("=xB2x4xIIIIB7x")
         self.bufsize = unpacker.offset - base
 
 
@@ -78,7 +78,7 @@ class NotifyEvent(xcffib.Event):
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
         self.state, self.time, self.root, self.window, self.kind, self.forced = (
-            unpacker.unpack("xB2xIIIBB14x")
+            unpacker.unpack("=xB2xIIIBB14x")
         )
         self.bufsize = unpacker.offset - base
 
