@@ -17,7 +17,7 @@ class DrmClipRect(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.x1, self.y1, self.x2, self.x3 = unpacker.unpack("hhhh")
+        self.x1, self.y1, self.x2, self.x3 = unpacker.unpack("=hhhh")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -46,7 +46,7 @@ class QueryVersionReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.dri_major_version, self.dri_minor_version, self.dri_minor_patch = (
-            unpacker.unpack("xx2x4xHHI")
+            unpacker.unpack("=xx2x4xHHI")
         )
         self.bufsize = unpacker.offset - base
 
@@ -63,7 +63,7 @@ class QueryDirectRenderingCapableReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.is_capable,) = unpacker.unpack("xx2x4xB")
+        (self.is_capable,) = unpacker.unpack("=xx2x4xB")
         self.bufsize = unpacker.offset - base
 
 
@@ -80,7 +80,7 @@ class OpenConnectionReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.sarea_handle_low, self.sarea_handle_high, self.bus_id_len = (
-            unpacker.unpack("xx2x4xIII12x")
+            unpacker.unpack("=xx2x4xIII12x")
         )
         self.bus_id = xcffib.List(unpacker, "c", self.bus_id_len)
         self.bufsize = unpacker.offset - base
@@ -103,7 +103,7 @@ class GetClientDriverNameReply(xcffib.Reply):
             self.client_driver_minor_version,
             self.client_driver_patch_version,
             self.client_driver_name_len,
-        ) = unpacker.unpack("xx2x4xIIII8x")
+        ) = unpacker.unpack("=xx2x4xIIII8x")
         self.client_driver_name = xcffib.List(
             unpacker, "c", self.client_driver_name_len
         )
@@ -122,7 +122,7 @@ class CreateContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.hw_context,) = unpacker.unpack("xx2x4xI")
+        (self.hw_context,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -138,7 +138,7 @@ class CreateDrawableReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.hw_drawable_handle,) = unpacker.unpack("xx2x4xI")
+        (self.hw_drawable_handle,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -165,7 +165,7 @@ class GetDrawableInfoReply(xcffib.Reply):
             self.back_x,
             self.back_y,
             self.num_back_clip_rects,
-        ) = unpacker.unpack("xx2x4xIIhhhhIhhI")
+        ) = unpacker.unpack("=xx2x4xIIhhhhIhhI")
         self.clip_rects = xcffib.List(unpacker, DrmClipRect, self.num_clip_rects)
         unpacker.pad(DrmClipRect)
         self.back_clip_rects = xcffib.List(
@@ -193,7 +193,7 @@ class GetDeviceInfoReply(xcffib.Reply):
             self.framebuffer_size,
             self.framebuffer_stride,
             self.device_private_size,
-        ) = unpacker.unpack("xx2x4xIIIIII")
+        ) = unpacker.unpack("=xx2x4xIIIIII")
         self.device_private = xcffib.List(unpacker, "I", self.device_private_size)
         self.bufsize = unpacker.offset - base
 
@@ -210,7 +210,7 @@ class AuthConnectionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.authenticated,) = unpacker.unpack("xx2x4xI")
+        (self.authenticated,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
