@@ -55,7 +55,7 @@ class ModeInfo(xcffib.Struct):
             self.vtotal,
             self.flags,
             self.privsize,
-        ) = unpacker.unpack("IHHHHIHHHH4xI12xI")
+        ) = unpacker.unpack("=IHHHHIHHHH4xI12xI")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -121,7 +121,7 @@ class QueryVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major_version, self.minor_version = unpacker.unpack("xx2x4xHH")
+        self.major_version, self.minor_version = unpacker.unpack("=xx2x4xHH")
         self.bufsize = unpacker.offset - base
 
 
@@ -150,7 +150,7 @@ class GetModeLineReply(xcffib.Reply):
             self.vtotal,
             self.flags,
             self.privsize,
-        ) = unpacker.unpack("xx2x4xIHHHHHHHHH2xI12xI")
+        ) = unpacker.unpack("=xx2x4xIHHHHHHHHH2xI12xI")
         self.private = xcffib.List(unpacker, "B", self.privsize)
         self.bufsize = unpacker.offset - base
 
@@ -168,7 +168,7 @@ class GetMonitorReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.vendor_length, self.model_length, self.num_hsync, self.num_vsync = (
-            unpacker.unpack("xx2x4xBBBB20x")
+            unpacker.unpack("=xx2x4xBBBB20x")
         )
         self.hsync = xcffib.List(unpacker, "I", self.num_hsync)
         unpacker.pad("I")
@@ -196,7 +196,7 @@ class GetAllModeLinesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.modecount,) = unpacker.unpack("xx2x4xI20x")
+        (self.modecount,) = unpacker.unpack("=xx2x4xI20x")
         self.modeinfo = xcffib.List(unpacker, ModeInfo, self.modecount)
         self.bufsize = unpacker.offset - base
 
@@ -213,7 +213,7 @@ class ValidateModeLineReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.status,) = unpacker.unpack("xx2x4xI20x")
+        (self.status,) = unpacker.unpack("=xx2x4xI20x")
         self.bufsize = unpacker.offset - base
 
 
@@ -229,7 +229,7 @@ class GetViewPortReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.x, self.y = unpacker.unpack("xx2x4xII16x")
+        self.x, self.y = unpacker.unpack("=xx2x4xII16x")
         self.bufsize = unpacker.offset - base
 
 
@@ -245,7 +245,7 @@ class GetDotClocksReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.flags, self.clocks, self.maxclocks = unpacker.unpack("xx2x4xIII12x")
+        self.flags, self.clocks, self.maxclocks = unpacker.unpack("=xx2x4xIII12x")
         self.clock = xcffib.List(unpacker, "I", (1 - (self.flags & 1)) * self.clocks)
         self.bufsize = unpacker.offset - base
 
@@ -262,7 +262,7 @@ class GetGammaReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.red, self.green, self.blue = unpacker.unpack("xx2x4xIII12x")
+        self.red, self.green, self.blue = unpacker.unpack("=xx2x4xIII12x")
         self.bufsize = unpacker.offset - base
 
 
@@ -278,7 +278,7 @@ class GetGammaRampReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.size,) = unpacker.unpack("xx2x4xH22x")
+        (self.size,) = unpacker.unpack("=xx2x4xH22x")
         self.red = xcffib.List(unpacker, "H", (self.size + 1) & (~1))
         unpacker.pad("H")
         self.green = xcffib.List(unpacker, "H", (self.size + 1) & (~1))
@@ -299,7 +299,7 @@ class GetGammaRampSizeReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.size,) = unpacker.unpack("xx2x4xH22x")
+        (self.size,) = unpacker.unpack("=xx2x4xH22x")
         self.bufsize = unpacker.offset - base
 
 
@@ -315,7 +315,7 @@ class GetPermissionsReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.permissions,) = unpacker.unpack("xx2x4xI20x")
+        (self.permissions,) = unpacker.unpack("=xx2x4xI20x")
         self.bufsize = unpacker.offset - base
 
 
@@ -331,7 +331,7 @@ class BadClockError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -353,7 +353,7 @@ class BadHTimingsError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -375,7 +375,7 @@ class BadVTimingsError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -397,7 +397,7 @@ class ModeUnsuitableError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -419,7 +419,7 @@ class ExtensionDisabledError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -441,7 +441,7 @@ class ClientNotLocalError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -463,7 +463,7 @@ class ZoomLockedError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
