@@ -64,7 +64,7 @@ class Rational(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.numerator, self.denominator = unpacker.unpack("ii")
+        self.numerator, self.denominator = unpacker.unpack("=ii")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -90,7 +90,7 @@ class Format(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.visual, self.depth = unpacker.unpack("IB3x")
+        self.visual, self.depth = unpacker.unpack("=IB3x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -117,7 +117,7 @@ class AdaptorInfo(xcffib.Struct):
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
         self.base_id, self.name_size, self.num_ports, self.num_formats, self.type = (
-            unpacker.unpack("IHHHBx")
+            unpacker.unpack("=IHHHBx")
         )
         self.name = xcffib.List(unpacker, "c", self.name_size)
         unpacker.pad(Format)
@@ -167,7 +167,7 @@ class EncodingInfo(xcffib.Struct):
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
         self.encoding, self.name_size, self.width, self.height = unpacker.unpack(
-            "IHHH2x"
+            "=IHHH2x"
         )
         self.rate = Rational(unpacker)
         unpacker.pad("c")
@@ -215,7 +215,7 @@ class Image(xcffib.Struct):
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
         self.id, self.width, self.height, self.data_size, self.num_planes = (
-            unpacker.unpack("IHHII")
+            unpacker.unpack("=IHHII")
         )
         self.pitches = xcffib.List(unpacker, "I", self.num_planes)
         unpacker.pad("I")
@@ -265,7 +265,7 @@ class AttributeInfo(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.flags, self.min, self.max, self.size = unpacker.unpack("IiiI")
+        self.flags, self.min, self.max, self.size = unpacker.unpack("=IiiI")
         self.name = xcffib.List(unpacker, "c", self.size)
         self.bufsize = unpacker.offset - base
 
@@ -299,7 +299,7 @@ class ImageFormatInfo(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.id, self.type, self.byte_order = unpacker.unpack("IBB2x")
+        self.id, self.type, self.byte_order = unpacker.unpack("=IBB2x")
         self.guid = xcffib.List(unpacker, "B", 16)
         (
             self.bpp,
@@ -318,10 +318,10 @@ class ImageFormatInfo(xcffib.Struct):
             self.vvert_y_period,
             self.vvert_u_period,
             self.vvert_v_period,
-        ) = unpacker.unpack("BB2xB3xIIIB3xIIIIIIIII")
+        ) = unpacker.unpack("=BB2xB3xIIIB3xIIIIIIIII")
         unpacker.pad("B")
         self.vcomp_order = xcffib.List(unpacker, "B", 32)
-        (self.vscanline_order,) = unpacker.unpack("B11x")
+        (self.vscanline_order,) = unpacker.unpack("=B11x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -430,7 +430,7 @@ class BadPortError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -452,7 +452,7 @@ class BadEncodingError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -474,7 +474,7 @@ class BadControlError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -496,7 +496,7 @@ class VideoNotifyEvent(xcffib.Event):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
-        self.reason, self.time, self.drawable, self.port = unpacker.unpack("xB2xIII")
+        self.reason, self.time, self.drawable, self.port = unpacker.unpack("=xB2xIII")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -531,7 +531,7 @@ class PortNotifyEvent(xcffib.Event):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
-        self.time, self.port, self.attribute, self.value = unpacker.unpack("xx2xIIIi")
+        self.time, self.port, self.attribute, self.value = unpacker.unpack("=xx2xIIIi")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -566,7 +566,7 @@ class QueryExtensionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major, self.minor = unpacker.unpack("xx2x4xHH")
+        self.major, self.minor = unpacker.unpack("=xx2x4xHH")
         self.bufsize = unpacker.offset - base
 
 
@@ -582,7 +582,7 @@ class QueryAdaptorsReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.num_adaptors,) = unpacker.unpack("xx2x4xH22x")
+        (self.num_adaptors,) = unpacker.unpack("=xx2x4xH22x")
         self.info = xcffib.List(unpacker, AdaptorInfo, self.num_adaptors)
         self.bufsize = unpacker.offset - base
 
@@ -599,7 +599,7 @@ class QueryEncodingsReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.num_encodings,) = unpacker.unpack("xx2x4xH22x")
+        (self.num_encodings,) = unpacker.unpack("=xx2x4xH22x")
         self.info = xcffib.List(unpacker, EncodingInfo, self.num_encodings)
         self.bufsize = unpacker.offset - base
 
@@ -616,7 +616,7 @@ class GrabPortReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.result,) = unpacker.unpack("xB2x4x")
+        (self.result,) = unpacker.unpack("=xB2x4x")
         self.bufsize = unpacker.offset - base
 
 
@@ -632,7 +632,7 @@ class QueryBestSizeReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.actual_width, self.actual_height = unpacker.unpack("xx2x4xHH")
+        self.actual_width, self.actual_height = unpacker.unpack("=xx2x4xHH")
         self.bufsize = unpacker.offset - base
 
 
@@ -648,7 +648,7 @@ class GetPortAttributeReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.value,) = unpacker.unpack("xx2x4xi")
+        (self.value,) = unpacker.unpack("=xx2x4xi")
         self.bufsize = unpacker.offset - base
 
 
@@ -664,7 +664,7 @@ class QueryPortAttributesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.num_attributes, self.text_size = unpacker.unpack("xx2x4xII16x")
+        self.num_attributes, self.text_size = unpacker.unpack("=xx2x4xII16x")
         self.attributes = xcffib.List(unpacker, AttributeInfo, self.num_attributes)
         self.bufsize = unpacker.offset - base
 
@@ -681,7 +681,7 @@ class ListImageFormatsReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.num_formats,) = unpacker.unpack("xx2x4xI20x")
+        (self.num_formats,) = unpacker.unpack("=xx2x4xI20x")
         self.format = xcffib.List(unpacker, ImageFormatInfo, self.num_formats)
         self.bufsize = unpacker.offset - base
 
@@ -699,7 +699,7 @@ class QueryImageAttributesReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.num_planes, self.data_size, self.width, self.height = unpacker.unpack(
-            "xx2x4xIIHH12x"
+            "=xx2x4xIIHH12x"
         )
         self.pitches = xcffib.List(unpacker, "I", self.num_planes)
         unpacker.pad("I")
